matminer.figrecipes.matplotlib package — matminer 0.1.8 documentation

# matminer.figrecipes.matplotlib package

## Subpackages

- matminer.figrecipes.matplotlib.examples package
  - Submodules
  - matminer.figrecipes.matplotlib.examples.heatmap_examples module
  - matminer.figrecipes.matplotlib.examples.xyscatter_examples module
  - Module contents

## Submodules

## matminer.figrecipes.matplotlib.plots module

class `matminer.figrecipes.matplotlib.plots.` `HeatMapPlot`(data, xlabels, ylabels, m_props=None, discrete_int=False)

  Bases: `object`

  `__init__`(data, xlabels, ylabels, m_props=None, discrete_int=False)

    Parameters: | data – 2D list or NP array xlabels – list of str ylabels – list of str m_props – discrete_int –

  `plot`(export_filename=None)

    Parameters: | export_filename – None for screen display, or ‘myplot.png’

class `matminer.figrecipes.matplotlib.plots.` `XYPlot`(data, m_props=None)

  Bases: `object`

  `__init__`(data, m_props=None)

    Parameters: | data – list of dict. Each dict must have ‘x’ and ‘y’, and optional things like ‘style’ and ‘color’ m_props –

  `plot`(export_filename=None)

    Parameters: | export_filename – None for screen display, or ‘myplot.png’

## Module contents